/*
 *  JCVSReport - Assess the Progress of a Java Project in CVS
 *
 *  This program is free software; you can redistribute it and/or modify it
 *  under the terms of the GNU General Public License.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along with
 *  this program; if not, write to the Free Software Foundation, Inc.,
 *  59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package ca.utoronto.JCVSReport.metric;

import java.util.*;
import java.sql.*;
import ca.utoronto.JCVSReport.*;

/**
 * Gather one metric from a revision of a file and add it to the
 * Bloof database
 * @author David James
 */
public abstract class BasicMetric implements Metric {

    // Configuration properties for this metric
    protected ResourceBundle props;

    // A unique id for the metric
    protected String id;

    // Prepared statement for inserting new metrics
    static final String INSERT_METRIC = "INSERT INTO Metric "
        + "(revision_id, metric_name, metric_value, function_name, class_name)"
        + " VALUES (?,?,?,?,?)";
    protected PreparedStatement insertMetric;

    /** Initialize Metric object from properties file
     * @param database Where to insert the metrics
     * @param id The name of the metric
     * @param props The properties of this metric as specified in the
     * .properties file */
    public void init(final MetricDatabase database, final String id,
            final ResourceBundle props) throws Exception {
        this.id = id;
        this.props = props;
        insertMetric = database.prepareStatement(INSERT_METRIC);
    }

}
