/*
 *  JCVSReport - Assess the Progress of a Java Project in CVS
 *
 *  This program is free software; you can redistribute it and/or modify it
 *  under the terms of the GNU General Public License.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along with
 *  this program; if not, write to the Free Software Foundation, Inc.,
 *  59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package ca.utoronto.JCVSReport.metric;

import java.util.Enumeration;
import java.util.MissingResourceException;
import java.util.ResourceBundle;
import java.util.StringTokenizer;

/**
 * This class allows you to graph individual metrics
 * without needing to provide a properties file. This
 * class describes the report by making the metric name,
 * and title available.
 *
 * @author David James
 */
public class MetricGraphProperties extends ResourceBundle {
    String metricName, metricTitle;

    /** Create a new ResourceBundle for the specified metric
     * @param metricName the name of the metric */
    public MetricGraphProperties(String metricName) {
        this.metricName = metricName;
        this.metricTitle = MetricSet.metricTitle(metricName);
    }

    /** Get a list of the keys supported by this bundle */
    public Enumeration getKeys() {
        return new StringTokenizer("metrics title");
    }

    /** Get an object from the bundle with the specified key
     * @param key the key */
    public Object handleGetObject(String key) {
        if (key == "metrics") {
            return metricName;
        } else if (key == "title") {
            return metricTitle;
        }

        throw new MissingResourceException(
           "Cannot find resource " + key,
           getClass().getName(), key
        );
    }
}
