/*
 *  JCVSReport - Assess the Progress of a Java Project in CVS
 *
 *  This program is free software; you can redistribute it and/or modify it
 *  under the terms of the GNU General Public License.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along with
 *  this program; if not, write to the Free Software Foundation, Inc.,
 *  59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package ca.utoronto.JCVSReport.metric;

import java.sql.*;
import java.util.*;
import org.jfree.data.time.*;


/**
 * The result of a query for a metric in the Metric Database
 * @author David James
 */
public class MetricRevision extends Vector {

    /** Initialize a MetricRevision object from the keys of a query
     * @param resultSet The query to read
     **/
    public MetricRevision(ResultSet resultSet) throws SQLException {
        int columnCount = resultSet.getMetaData().getColumnCount();
        for (int i = 1; i <= columnCount; i++) {
            add(resultSet.getObject(i));
        }
    }

    /** Create a MetricRevision object from a list
     * @param list the list to read from */
    public MetricRevision(List list) {
        super(list);
    }

    /** Create a MetricRevision object from a string
     * @param metricName metric name
     * @param file the filename changed in this revision
     * @param tstamp timestamp of change
     * @param metricValue value of metric
     * @param developer the name of the developer who committed this change
     */
    public MetricRevision(String metricName, String file, Timestamp tstamp,
                double metricValue, String developer) {
        add(metricName);
        add(file);
        add(tstamp);
        add(new Double(metricValue));
        add(developer);
    }

    /** Get the title */
    public String getMetricName() {
        return (String) get(0);
    }

    /** Get the filename */
    public String getFile() {
        return (String) get(1);
    }

    /** Get the timestamp */
    public Timestamp getTimestamp() {
        return (Timestamp) get(2);
    }

    /** Get the timestamp as a day */
    public Day getDay() {
        return new Day(getTimestamp());
    }

    /** Get the metric value */
    public double getMetricValue() {
        return ((Number) get(3)).doubleValue();
    }

    /** Get the metric value */
    public String getDeveloper() {
        return (String) get(4);
    }


    /** Sort this metric by metric name and developer
     * Note: this comparator imposes orderings that are inconsistent with
     * equals
     * */
    public static Comparator byDeveloper() {
        return new Comparator() {
            public int compare(Object o1, Object o2) {
                MetricRevision m1 = (MetricRevision) o1;
                MetricRevision m2 = (MetricRevision) o2;
                if (m1.getMetricName().equals(m2.getMetricName())) {
                    return m1.getDeveloper().compareTo(m2.getDeveloper());
                } else {
                    return m1.getMetricName().compareTo(m2.getMetricName());
                }
            }
        };
    }

    /** Sort this metric by metric name and file
     * Note: this comparator imposes orderings that are inconsistent with
     * equals
     *  */
    public static Comparator byFile() {
        return new Comparator() {
            public int compare(Object o1, Object o2) {
                MetricRevision m1 = (MetricRevision) o1;
                MetricRevision m2 = (MetricRevision) o2;
                if (m1.getMetricName().equals(m2.getMetricName())) {
                    return m1.getFile().compareTo(m2.getFile());
                } else {
                    return m1.getMetricName().compareTo(m2.getMetricName());
                }
            }
        };
    }


}
