/*
 *  JCVSReport - Assess the Progress of a Java Project in CVS
 *
 *  This program is free software; you can redistribute it and/or modify it
 *  under the terms of the GNU General Public License.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along with
 *  this program; if not, write to the Free Software Foundation, Inc.,
 *  59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package ca.utoronto.JCVSReport.metric;

import java.util.Comparator;
import java.util.Iterator;

import java.util.*;

/**
 * Store and retrieve metric values according to
 * the specified Comparator object
 *
 * @author David James
 * */
public class MetricRevisionMap extends TreeMap {

    /** Create a new MetricRevisionMap which uses the specified Comparator
     * to sort values and determine equality
     * @param comp The Comparator
     */
    public MetricRevisionMap(Comparator comp) {
        super(comp);
    }

    /** Associate a revision with a number
     * @param key The revision
     * @param value The integer */
    public void putDouble(Object key, double value) {
        super.put(key, new Double(value));
    }

    /** Get the number associated with a revision object
     * @param key The revision object */
    public double getDouble(Object key) {
        if (containsKey(key)) {
            return ((Number) super.get(key)).doubleValue();
        } else {
            return 0;
        }
    }

    /** Retrieve sum of each metric
     * @param metricName the name of the metric */
    public double sum(String metricName) {
        double total = 0;
        for (Iterator it = keySet().iterator(); it.hasNext();) {
            MetricRevision key = ((MetricRevision) it.next());
            if (key.getMetricName().equals(metricName)) {
                total += getDouble(key);
            }
        }
        return total;

    }

}
