/*
 *  JCVSReport - Assess the Progress of a Java Project in CVS
 *
 *  This program is free software; you can redistribute it and/or modify it
 *  under the terms of the GNU General Public License.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along with
 *  this program; if not, write to the Free Software Foundation, Inc.,
 *  59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package ca.utoronto.JCVSReport.metric;

import java.util.*;
import ca.utoronto.JCVSReport.*;

/**
 * MetricSet: Gather a set of metric from a revision of a file and add it to
 * the Bloof database
 *
 * @author David James
 */
public class MetricSet {

    HashMap metrics = new HashMap();
    MetricDatabase database;

    /** Get the properties for a particular metric
     * @param metricName the name of the metric */
    protected static ResourceBundle metricProps(String metricName) {
        // Find 'metricName'.properties in the directory corresponding to
        // the ca.utoronto.JCVSReport.properties.metric package.
        String fileName =
            "ca.utoronto.JCVSReport.metric.properties." + metricName;
        return ResourceBundle.getBundle(fileName);
    }

    /** Get the title of a particular metric
     * @param metricName the name of the metric */
    public static String metricTitle(String metricName) {
        return metricProps(metricName).getString("title");
    }

    /** Get the title of a particular metric
     * @param metricName the name of the metric */
    private Metric createMetric(String metricName) throws Exception {
        // Create this new metric
        ResourceBundle props = metricProps(metricName);
        String className = props.getString("class");
        Metric metric = (Metric) Class.forName(className).newInstance();

        // Initialize and return this new metric class
        metric.init(database, metricName, props);
        return metric;
    }

    /** Initialize our set of Metrics
     * @param database The database we should update */
    public MetricSet(final MetricDatabase database) {
        this.database = database;
    }


    /** Add a metric to this metricSet
     * @param metricName The metric we want to add
     * @throws Exception if any of the metrics cannot be loaded */
    public void addMetric(final String metricName) throws Exception {

        // Only add metrics which are not already added.
        if (!metrics.containsKey(metricName)) {
            metrics.put(metricName, createMetric(metricName));
        }
    }

    /** Process the contents of a revision of a file with each metric
     * @param revisionId A unique ID for this revision of this file
     * @param contents The contents of the file as a string
     * @throws Exception if this revision cannot be processed
     * */
    public void processRevision(final String revisionId,
            final String contents) throws Exception {
        // Process this revision with every metric
        for (Iterator it = metrics.values().iterator(); it.hasNext();) {
            Metric metric = (Metric) it.next();
            metric.processRevision(revisionId, contents);
        }
    }

}
