/*
 *  JCVSReport - Assess the Progress of a Java Project in CVS
 *
 *  This program is free software; you can redistribute it and/or modify it
 *  under the terms of the GNU General Public License.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along with
 *  this program; if not, write to the Free Software Foundation, Inc.,
 *  59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package ca.utoronto.JCVSReport.metric;

import java.util.regex.*;


/**
 * RegexLineCounter: Class that is used to count number of newlines
 * for the specified regular expression in the search string.
 *
 * @author David James
 * @author Olga Rodimina
 */
public class RegexLineCounter extends RegexMatchCounter {
    /** A regular expression for matching newlines */
    static Pattern newline = Pattern.compile("\n");

    /**
     * Returns number of newlines matched by a specified regular expression
     *
     * @param contents The contents of the file as a string
     * @param regex regular expression to match
     */
    public int countMatches(final String contents, final Pattern regex) {
        int numMatches = 0;

        /* Find all of the matches for our regular expression */
        Matcher matcher = regex.matcher(contents);

        while (matcher.find()) {
            /* Count the newlines within each match */
            Matcher newlineMatcher = newline.matcher(matcher.group(0));

            while (newlineMatcher.find()) {
                numMatches++;
            }
        }

        return numMatches;
    }
}
