/*
 *  JCVSReport - Assess the Progress of a Java Project in CVS
 *
 *  This program is free software; you can redistribute it and/or modify it
 *  under the terms of the GNU General Public License.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along with
 *  this program; if not, write to the Free Software Foundation, Inc.,
 *  59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package ca.utoronto.JCVSReport.metric;

import ca.utoronto.JCVSReport.*;

import java.util.*;
import java.util.regex.*;


/**
 * Metric: Gather one metric from a revision of a file and add it to the Bloof
 * database
 *
 * @author David James
 * @author Olga Rodimina
 */
public class RegexMatchCounter extends BasicMetric {

    /** The regular expression we want to match */
    Pattern regex;

    /**
     * Initialize Metric from properties file
     *
     * @param database Where to insert the metrics
     * @param id The id number of the metric
     * @param props The properties of this metric as specified in the
     *        .properties file
     *
     * @throws Exception
     */
    public void init(final MetricDatabase database, final String id,
        final ResourceBundle props) throws Exception {
        super.init(database, id, props);

        /* Compile our regular expressions in advance so that we can
         * use them later to process each revision */
        regex = Pattern.compile(props.getString("regex"));
    }

    /**
     * Process the contents of a revision of a file with this metric
     *
     * @param revisionId A unique ID for this revision of this file
     * @param contents The contents of the file as a string
     *
     * @throws Exception
     */
    public void processRevision(final String revisionId, final String contents)
        throws Exception {
        int numMatches = countMatches(contents, regex);

        /* Insert our newly gathered metric into the database */
        insertMetric.setString(1, revisionId);
        insertMetric.setString(2, id);
        insertMetric.setInt(3, numMatches);
        insertMetric.executeUpdate();
    }

    /**
     * Returns number of matches for a specified regular expression
     *
     * @param contents The contents of the file as a string
     * @param regex regular expression to match
     */
    public int countMatches(final String contents, final Pattern regex) {
        int numMatches = 0;

        /* Find all of the matches for our regular expression */
        Matcher matcher = regex.matcher(contents);

        while (matcher.find()) {
            numMatches++;
        }

        return numMatches;
    }
}
