/*
 *  JCVSReport - Assess the Progress of a Java Project in CVS
 *
 *  This program is free software; you can redistribute it and/or modify it
 *  under the terms of the GNU General Public License.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along with
 *  this program; if not, write to the Free Software Foundation, Inc.,
 *  59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package ca.utoronto.JCVSReport.metric;

import java.util.regex.*;

import net.sourceforge.pmd.TargetJDK1_4;
import net.sourceforge.pmd.ast.*;
import java.io.*;


/**
 * This class is an adaptation of RegexLineCounter, targeted towards parsing
 * .java source files, by ways of Abstract Syntax Trees, via PMD.
 *
 * @author David James
 * @author Olga Rodimina
 * @author Jeffrey Magder
 */
public class SyntaxTreeRegexMatchCounter extends RegexMatchCounter {

    /**
     * Convert Java source code into an abstract syntax tree
     * @param reader Java Source Code
     **/
   public String getJavaSyntaxTree(Reader reader) {
        // Create Java 1.4 parser
        JavaParser parser = (new TargetJDK1_4()).createParser(reader);

        // PMD as is will dump out the parse tree to STDOUT.  However, we want
        // to patch this output through to the regular expression matcher.
        // Therefore we will temporarily redirect stdout to a
        // ByteArrayOutputStream.

        // Get a backup of where stdout is currently pointing to, because
        // we are about to redirect it.
        PrintStream originalStream = System.out;

        // Redirect stdout to a ByteArrayOutputStream
        ByteArrayOutputStream buf = new ByteArrayOutputStream();
        System.setOut(new PrintStream(buf));

        // Output the syntax tree to our special buffer within MyPrintStream.
        try {
            parser.CompilationUnit().dump("");
        } catch (ParseException ex) {
            // Print empty parse tree
            System.out.println("");
        }

        // Set standard out back to where it was before method invocation.
        System.setOut(originalStream);

        return buf.toString();
    }

   /**
    * Returns number of matches for a specified regular expression
    * in the Java Syntax Tree parsed from the specified string
    *
    * @param contents The contents of the file as a string
    * @param regex regular expression to match
    */
   public int countMatches(final String contents, final Pattern regex) {
       String syntaxTree = getJavaSyntaxTree(new StringReader(contents));
       return super.countMatches(syntaxTree, regex);
   }
}
