/*
 *  JCVSReport - Assess the Progress of a Java Project in CVS
 *
 *  This program is free software; you can redistribute it and/or modify it
 *  under the terms of the GNU General Public License.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along with
 *  this program; if not, write to the Free Software Foundation, Inc.,
 *  59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package ca.utoronto.JCVSReport.report;

import java.sql.*;
import java.util.*;

import org.jfree.chart.ChartFactory;
import org.jfree.chart.JFreeChart;
import org.jfree.data.general.*;
import org.jfree.data.category.*;
import org.jfree.chart.plot.*;

import ca.utoronto.JCVSReport.metric.*;

/**
 * Show how much each developer contributes to several metrics
 * over time using a bar graph
 *
 * @author David James
 */
 public class BarGraph extends BasicGraph {

     /** Build a dataset object from an SQL query
      * NOTE: We assume that the SQL query returns values sorted by date */
     protected Dataset getDataset() throws Exception {

         // Execute the query and loop through the MetricRevisions
         ResultSet metricRevisions = executeQuery();
         while (metricRevisions.next()) {
             // Get details on this datapoint
             MetricRevision revision = new MetricRevision(metricRevisions);

             // Put keys into ResultMap
             storeMetricValue(revision);
         }

         DefaultCategoryDataset dataset = new DefaultCategoryDataset();

         /* Build category dataset */
         for (Iterator it = devMap.keySet().iterator(); it.hasNext();) {
             MetricRevision revision = (MetricRevision) it.next();
             String metricName = getSeriesLabel(revision);
             if (perDeveloper) {
                 double value = devMap.getDouble(revision);
                 dataset.setValue(value, metricName, revision.getDeveloper());
             } else {
                 dataset.setValue(devMap.sum(metricName), metricName, "");
             }
         }
         return dataset;
     }

     /** Build a chart from a seriesCollection */
     protected JFreeChart getChart() throws Exception {
         return ChartFactory.createBarChart
         (getTitle(),                      // Title
          getXLabel(),                     // X-Axis label
          getYLabel(),                     // Y-Axis label
          (CategoryDataset) getDataset(),  // Dataset
          PlotOrientation.VERTICAL,        // Orientation
          true,                            // Show legend
          true,                            // Use tooltips
          false                            // Configure chart to generate URLs?
         );
     }

 }
