/*
 *  JCVSReport - Assess the Progress of a Java Project in CVS
 *
 *  This program is free software; you can redistribute it and/or modify it
 *  under the terms of the GNU General Public License.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along with
 *  this program; if not, write to the Free Software Foundation, Inc.,
 *  59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package ca.utoronto.JCVSReport.report;

import java.io.*;
import java.util.*;

import ca.utoronto.JCVSReport.MetricDatabase;

/**
 * Write a single graph out to an HTML file
 * @author David James
 */
public interface Graph {

    /** Initialize Graph from properties file
     * @param database Where to get our data
     * @param id A unique ID for this graph
     * @param props Properties of this graph
     * */
    void init(MetricDatabase database, String id, ResourceBundle props)
        throws Exception;

    /** Output this report to an HTML file
     * @param output Where to write the HTML report
     * @param directory Where to store images
     * */
    void write(PrintWriter output, File directory) throws Exception;

    /** Get the title of the graph */
    String getTitle();

    /** Set whether we should report this metric per developer *
     * @param value whether to report the metric */
    void setPerDeveloper(boolean value);

    /** Get a list of metrics supported by this graph */
    String[] getMetricNames();
}
