/*
 *  JCVSReport - Assess the Progress of a Java Project in CVS
 *
 *  This program is free software; you can redistribute it and/or modify it
 *  under the terms of the GNU General Public License.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along with
 *  this program; if not, write to the Free Software Foundation, Inc.,
 *  59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package ca.utoronto.JCVSReport.report;

import org.jfree.chart.ChartFactory;
import org.jfree.chart.JFreeChart;
import org.jfree.data.general.*;
import org.jfree.data.category.*;
import org.jfree.util.*;

/**
 * Show how much each developer contributes to a particular metric
 * over time
 *
 * @author David James
 */
 public class PieGraph extends BarGraph {

     /** Build a chart from a dataset */
     protected JFreeChart getChart() throws Exception {
         // If they ask to display a perDeveloper graph with more than one
         // metric, display a bar chart instead.
         if (perDeveloper && getMetricNames().length > 1) {
             return super.getChart();
         } else {

             PieDataset dataset = new CategoryToPieDataset(
                 (CategoryDataset) getDataset(), getTableOrder(), 0);

             return ChartFactory.createPieChart
             (getTitle(),      // Title
              dataset,         // Dataset
              true,            // Show legend
              true,            // Use tooltips
              false            // Configure chart to generate URLs?
             );
         }
     }

    /** Decide whether to display the developer names
     *  or the metric names
     */
    TableOrder getTableOrder() {
        if (perDeveloper) {
            return TableOrder.BY_ROW;
        } else {
            return TableOrder.BY_COLUMN;
        }
    }

 }
