CREATE TABLE Project
(
    name       VARCHAR(30) NOT NULL,
    scmsystem  VARCHAR(30) NOT NULL,
    login 	   VARCHAR(30) NOT NULL,
    passwd   VARCHAR(30),
    location   VARCHAR(500) NOT NULL,
    connmethod VARCHAR(10),
    module	   VARCHAR(30),
    UNIQUE(name)
);


CREATE TABLE Developer
(
    login       VARCHAR(30) NOT NULL,
    UNIQUE(login),
    CONSTRAINT  devel_pk PRIMARY KEY (login)
);

CREATE TABLE File
(
    pathname    VARCHAR (500) NOT NULL,
    name        VARCHAR(100) NOT NULL,
    description TEXT,
    UNIQUE(pathname),
    CONSTRAINT  file_pk PRIMARY KEY (pathname)

);

CREATE TABLE Revision
(
    revision_id INTEGER DEFAULT UNIQUEKEY('Revision'),
    file        VARCHAR(500) NOT NULL,
    tstamp 		TIMESTAMP NOT NULL,
    developer   VARCHAR(30) NOT NULL,
    version     VARCHAR(30) NOT NULL,
    lines_add   INTEGER,
    lines_del   INTEGER,
    description TEXT,
    UNIQUE(file, tstamp, version),
    CONSTRAINT  rev_devel_fk FOREIGN KEY (developer) REFERENCES Developer,
    CONSTRAINT  rev_file_fk FOREIGN KEY (file) REFERENCES File,
    CONSTRAINT  rev_pk PRIMARY KEY (revision_id)
);

CREATE TABLE DeletedFile
(
    file    	VARCHAR (500) NOT NULL,
    tstamp		TIMESTAMP NOT NULL,
    UNIQUE(file, tstamp),
    CONSTRAINT  del_file_fk FOREIGN KEY (file) REFERENCES File
);

CREATE TABLE Metric
(
    id INTEGER DEFAULT UNIQUEKEY('Metric'),
    revision_id INTEGER NOT NULL,
    metric_name VARCHAR(30) NOT NULL,
    metric_value INTEGER NOT NULL,
    function_name VARCHAR(30),
    class_name VARCHAR(30),
    CONSTRAINT metric_fk FOREIGN KEY (revision_id) REFERENCES Revision,
    CONSTRAINT metric_pk PRIMARY KEY (id)
);


CREATE TABLE CVSOperation
(
    id INTEGER DEFAULT UNIQUEKEY('CVSOperation'),
    operation CHAR(1) NOT NULL,
    revision_id INTEGER,
    tstamp TIMESTAMP NOT NULL,
    developer VARCHAR(30) NOT NULL,
    CONSTRAINT cvs_fk1 FOREIGN KEY (revision_id) REFERENCES Revision,
    CONSTRAINT cvs_fk2 FOREIGN KEY (developer) REFERENCES Developer
);

CREATE VIEW MetricRevision AS
    SELECT Metric.revision_id, file, version, tstamp, developer, lines_add, lines_del,
           metric_name, metric_value, function_name, class_name
    FROM Metric, Revision
    WHERE Metric.revision_id = Revision.revision_id;

CREATE VIEW CVSOperationRevision AS
    SELECT Revision.revision_id, file, version,
           operation, CVSOperation.tstamp, CVSOperation.developer
    FROM CVSOperation, Revision
    WHERE CVSOperation.revision_id = Revision.revision_id;
