/*
 *  JCVSReport - Assess the Progress of a Java Project in CVS
 *
 *  This program is free software; you can redistribute it and/or modify it
 *  under the terms of the GNU General Public License.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along with
 *  this program; if not, write to the Free Software Foundation, Inc.,
 *  59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package ca.utoronto.JCVSReport;

import ca.utoronto.JCVSReport.cvsPlugin.*;
import ca.utoronto.JCVSReport.metric.*;
import ca.utoronto.JCVSReport.report.*;
import ca.utoronto.SimpleProcess.*;

import junit.framework.Test;
import junit.framework.TestResult;
import junit.framework.TestSuite;


/**
 * Test Suite incorporating all the unit tests
 *
 * @author Olga Rodimina
 */
public class AllTests {

    /**
     * Create Test suite incorporating tests from all other testsuites
     *
     * @return Test suite incorporating tests from all other testsuites
     */
    public static Test suite() {
        TestSuite suite = new TestSuite("Test for ca.utoronto.JCVSReport");

        // Add all tests and testsuites here
        suite.addTestSuite(ConfigTest.class);
        suite.addTestSuite(PresentationTest.class);
        suite.addTestSuite(MetricRevisionMapTest.class);
        suite.addTestSuite(MetricDatabaseConnectionTest.class);
        suite.addTestSuite(MetricDatabaseTest.class);
        suite.addTest(AllSimpleProcessTests.suite());
        suite.addTest(AllReportTests.suite());
        suite.addTest(AllMetricTests.suite());
        suite.addTest(AllCvsPluginTests.suite());

        return suite;
    }

    /** Run the entire test suite */
    public static void main() {
        System.out.println("Running test suite...");

        TestResult result = new TestResult();
        suite().run(result);

        if (result.errorCount() == 0) {
            System.out.println("All tests successful!");
        } else {
            System.out.println(
                    result.errorCount() + " errors.");
            System.out.println("Please read docs/INSTALL.PDF for instructions");
            System.out.println("on setting up JCVSReport.");
        }
        return;
    }
}
