/*
 *  JCVSReport - Assess the Progress of a Java Project in CVS
 *
 *  This program is free software; you can redistribute it and/or modify it
 *  under the terms of the GNU General Public License.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along with
 *  this program; if not, write to the Free Software Foundation, Inc.,
 *  59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package ca.utoronto.JCVSReport;

import junit.framework.TestCase;

import net.sf.bloof.*;
import net.sf.bloof.db.*;
import net.sf.bloof.scm.cvsplugin.*;

import java.io.*;


/**
 * JUnit test for Config
 *
 * @author Olga Rodimina
 */
public class ConfigTest extends TestCase {
    Config config;

    /**
     * Sets up config object that will be tested
     *
     * @see TestCase#setUp()
     */
    protected void setUp() throws Exception {
        config = new Config();

        // Create file for testing
        String fileContents = "project=408project\n"
            + "cvsroot=/home/olya/c408h11\n" + "cvsmodule=408project\n"
            + "cvspassword=\n" + "db=internal\n" + "graphs=Lines,Commits\n";

        config.load(new ByteArrayInputStream(fileContents.getBytes()));
    }

    /**
     * Test cvs method. This method should create and return CvsAccess   that
     * will be used to access the cvs repository
     *
     * @throws NoSuchFieldException
     */
    public void testCvs() throws Exception {
        CvsAccess cvsAccess = config.cvs();
        assertEquals(cvsAccess.getCvsRoot(), ":local:/home/olya/c408h11");
        assertEquals(cvsAccess.getModuleName(), "408project");
    }

    /**
     * This method tests testDb(). testDb should create and return appropriate
     * DbAccess object that will be used to access the database
     *
     * @throws NoSuchFieldException
     */
    public void testDb() throws NoSuchFieldException {
        DbAccess dbAccess = config.db();
        assertTrue(dbAccess.equals(Bloof.INTERNAL_DATABASE));
    }

    /**
     * This test case tests to see if names of the graphs specified by the user
     * were set correctly in the config object
     *
     * @throws NoSuchFieldException
     */
    public void testGetGraphNames() throws NoSuchFieldException {
        String[] graphNames = config.getGraphNames();

        assertEquals(graphNames[0], "Lines");
        assertEquals(graphNames[1], "Commits");
    }

}
