/*
 *  JCVSReport - Assess the Progress of a Java Project in CVS
 *
 *  This program is free software; you can redistribute it and/or modify it
 *  under the terms of the GNU General Public License.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along with
 *  this program; if not, write to the Free Software Foundation, Inc.,
 *  59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package ca.utoronto.JCVSReport;

import java.io.IOException;
import java.sql.Connection;
import java.sql.SQLException;

import junit.framework.TestCase;
import net.sf.bloof.Bloof;
import net.sf.bloof.db.*;

/**
 *
 * @author Polina Gohshtein
 */
public class MetricDatabaseConnectionTest extends TestCase {

    /** testConnectionToDefaultDatabase: Make sure that a connection
     * can be created for the default internal bloof database
     * and used to initialize a MetricDatabase.
     */
    public void testConnectionToDefaultDatabase() {
        Database db = null;
        Connection conn = null;
        try {
            conn = McKoiControl.create(Bloof.INTERNAL_DATABASE);
        } catch (SQLException e) {
            fail("Start of internal Database failed." + e.toString());
        } catch (IOException e) {
            fail("Start of internal Database failed." + e.toString());
        }
        assertNotNull(conn);
        try {
            db = new MetricDatabase(conn);
        } catch (SQLException e) {
            fail("Connection to Database failed." + e.toString());
        }

        try {
            db.close();
        } catch (SQLException e) {
            fail("Failed to close the database." + e.toString());
        } catch (IOException e) {
            fail("Failed to close the database." + e.toString());
        }
    }

    /** testConnectionToOtherLocalDatabase: Make sure that a connection
     * can be created for the default internal bloof database
     * and used to initialize a MetricDatabase.
     */
    public void testConnectionToOtherLocalDatabase() {
        Database db = null;
        Connection conn = null;
        try {
            conn = McKoiControl.create(new DefaultDbAccess(
                    "MyDb", "test", "test",
                    Bloof.LOCAL_BLOOF_DIR + "/testdir"));
        } catch (SQLException e) {
            fail("Start of internal Database failed." + e.toString());
        } catch (IOException e) {
            fail("Start of internal Database failed." + e.toString());
        }
        assertNotNull(conn);
        try {
            db = new MetricDatabase(conn);
        } catch (SQLException e) {
            fail("Connection to Database failed." + e.toString());
        }

        try {
            db.close();
        } catch (SQLException e) {
            fail("Failed to close the database." + e.toString());
        } catch (IOException e) {
            fail("Failed to close the database." + e.toString());
        }
    }
}