/*
 *  JCVSReport - Assess the Progress of a Java Project in CVS
 *
 *  This program is free software; you can redistribute it and/or modify it
 *  under the terms of the GNU General Public License.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along with
 *  this program; if not, write to the Free Software Foundation, Inc.,
 *  59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package ca.utoronto.JCVSReport.cvsPlugin;

import java.io.StringReader;
import java.util.Iterator;
import java.util.Vector;
import java.sql.Timestamp;

import junit.framework.TestCase;

/**
 * HistoryParserTest
 * @author Polina Gohshtein
 */
public class HistoryParserTest extends TestCase {
    /**
     * @see TestCase#setUp()
     */
    protected void setUp() throws Exception {
        super.setUp();
    }

    /**
     * @see TestCase#tearDown()
     */
    protected void tearDown() throws Exception {
        super.tearDown();
    }

    /** testParsingFileSpecificOperation verifies that
     * the HistoryParser correctly parses a line from the
     * history output where the operation is file specific.
     */
    public void testParsingFileSpecificOperation() {
        String input = "A 2005-02-14 19:25 +0000 g2james "
            + " 1.1  MetricDatabase.java "
            + " 408project/src/ca/utoronto/JCVSReport == <remote>";
        String cvsroot = "cvsroot";

        History targetRecord = new History();
        targetRecord.setOperation("A");
        targetRecord.setTimestamp(Timestamp.valueOf("2005-02-14 19:25:00.0"));
        targetRecord.setUser("g2james");
        targetRecord.setRevision("1.1");
        targetRecord.setFile("MetricDatabase.java");
        targetRecord.setPath("cvsroot/408project/src/ca/utoronto/JCVSReport");

        HistoryParser parser =
            new HistoryParser(new StringReader(input), cvsroot);

        parser.run();
        Vector history = parser.getHistory();
        Iterator it = history.iterator();
        if (it.hasNext()) {
            History record = (History) it.next();
            assertTrue(record.equals(targetRecord));
        } else {
            fail("Iterator should not be empty.");
        }
    }

    /** testParsingRevisionlessOperation verifies that
     * the HistoryParser correctly parses a line from the
     * history output where the operation is file specific,
     * but does not have a revision associated with it.
     */
    public void testParsingRevisionlessOperation() {
        String input = "W 2005-01-29 03:56 +0000 g2polgoh"
            + " database.ddl 408project/lib/bloof-1.0/src/java/net/sf/bloof/db"
            + " == <remote>/lib/bloof-1.0/src/java/net/sf/bloof/db";
        String cvsroot = "cvsroot";

        History targetRecord = new History();
        targetRecord.setOperation("W");
        targetRecord.setTimestamp(Timestamp.valueOf("2005-01-29 03:56:00.0"));
        targetRecord.setUser("g2polgoh");
        targetRecord.setRevision(null);
        targetRecord.setFile("database.ddl");
        targetRecord.setPath(
                "cvsroot/408project/lib/bloof-1.0/src/java/net/sf/bloof/db");

        HistoryParser parser =
            new HistoryParser(new StringReader(input), cvsroot);

        parser.run();
        Vector history = parser.getHistory();
        Iterator it = history.iterator();
        if (it.hasNext()) {
            History record = (History) it.next();
            assertTrue(record.equals(targetRecord));
        } else {
            fail("Iterator should not be empty.");
        }
    }

    /** testParsingMultipleOperations verifies that
     * the HistoryParser can parse multiple operations.
     */
    public void testParsingMultipleOperations() {
        String input = "A 2005-02-14 19:25 +0000 g2james "
            + " 1.1  MetricDatabase.java "
            + " 408project/src/ca/utoronto/JCVSReport == <remote>\n"
            + "W 2005-01-29 03:56 +0000 g2polgoh"
            + " database.ddl 408project/lib/bloof-1.0/src/java/net/sf/bloof/db"
            + " == <remote>/lib/bloof-1.0/src/java/net/sf/bloof/db";
        String cvsroot = "cvsroot";

        HistoryParser parser =
            new HistoryParser(new StringReader(input), cvsroot);

        parser.run();
        Vector history = parser.getHistory();
        // There should be 2 history records in the vector
        assertEquals(history.size(), 2);
    }

}
