/*
 *  JCVSReport - Assess the Progress of a Java Project in CVS
 *
 *  This program is free software; you can redistribute it and/or modify it
 *  under the terms of the GNU General Public License.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along with
 *  this program; if not, write to the Free Software Foundation, Inc.,
 *  59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package ca.utoronto.JCVSReport.metric;

import junit.framework.TestCase;
import java.util.*;

/**
 * Test cases for MetricGraphProperties
 *
 * @author David James
 */
public class MetricGraphPropertiesTest extends TestCase {

    MetricGraphProperties m;

    /** Set up for tests */
    public void setUp() {
        m = new MetricGraphProperties("LinesOfCode");
    }

    /** Test the constructor */
    public void testMetricGraphProperties() {
        // Test for files that don't exist
        boolean threwError = false;
        try {
            new MetricGraphProperties("NonExistent");
        } catch (MissingResourceException ex) {
            threwError = true;
        }
        assertTrue(threwError);
    }

    /**
     * Class under test for Enumeration getKeys()
     */
    public void testGetKeys() {
        Enumeration e = m.getKeys();

        // Test for elements that exist
        assertEquals("metrics", e.nextElement());
        assertEquals("title", e.nextElement());
        assertTrue(!e.hasMoreElements());

        // Test for elements that don't exist
        boolean threwError = false;
        try {
            e.nextElement();
        } catch (NoSuchElementException ex) {
            threwError = true;
        }
        assertTrue(threwError);
    }


    /**
     * Class under test for Object handleGetObject(String)
     */
    public void testHandleGetObjectString() {
        // Test for elements that exist
        assertEquals("Lines of Code", m.getString("title"));
        assertEquals("LinesOfCode", m.getString("metrics"));

        // Test for elements that don't exist
        boolean threwError = false;
        try {
            m.getString("non-existent-key");
        } catch (MissingResourceException ex) {
            threwError = true;
        }
        assertTrue(threwError);
    }

}
