/*
 *  JCVSReport - Assess the Progress of a Java Project in CVS
 *
 *  This program is free software; you can redistribute it and/or modify it
 *  under the terms of the GNU General Public License.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along with
 *  this program; if not, write to the Free Software Foundation, Inc.,
 *  59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package ca.utoronto.JCVSReport.metric;

import junit.framework.TestCase;


/**
 * A test for MetricRevisionMap
 *
 * @author David James
 */
public class MetricRevisionMapTest extends TestCase {
    MetricRevisionMap map;

    /* Precision for doubles */
    double epsilon = 1e-6;

    /* Test data */
    MetricRevision[] keys = {
        new MetricRevision("mn1", "file1", null, 0.0, null),
        new MetricRevision("mn1", "file2", null, 0.0, null),
        new MetricRevision("mn1", "file3", null, 0.0, null),
        new MetricRevision("mn1", "file4", null, 0.0, null),
        new MetricRevision("mn2", "file1", null, 0.0, null),
        new MetricRevision("mn2", "file2", null, 0.0, null),
        new MetricRevision("mn2", "file3", null, 0.0, null),
        new MetricRevision("mn2", "file4", null, 0.0, null),
        new MetricRevision("mn1", "file1", null, 3.0, null),
    };
    double[] sums = {56, 56, 56, 56, 45, 45, 45, 45, 56};
    double[] values = {5.4, 20, 0, 25, 36, 10, 0, -1, 11};
    double[] get = {11, 20, 0, 25, 36, 10, 0, -1, 11};


    /**
     * Set up test SumMap
     *
     * @see TestCase#setUp()
     */
    protected void setUp() {
        map = new MetricRevisionMap(MetricRevision.byFile());

        for (int i = 0; i < keys.length; i++) {
            map.putDouble(keys[i], values[i]);
        }
    }

    /**
     * Test if the sum of values contained in MetricRevisionMap is
     * calculated correctly
     */
    public void testSum() {
        for (int i = 0; i < keys.length; i++) {
            assertEquals(sums[i], map.sum(keys[i].getMetricName()), epsilon);
        }
    }

    /**
     * Test if the sum of values contained in MetricRevisionMap is
     * calculated correctly
     */
    public void testGet() {
        for (int i = 0; i < keys.length; i++) {
            assertTrue(map.containsKey(keys[i]));
            assertTrue(map.containsValue(new Double(get[i])));
            assertEquals(new Double(get[i]), map.get(keys[i]));
        }
    }

    /**
     * Test if the sum of values contained in MetricRevisionMap is
     * calculated correctly
     */
    public void testGetDouble() {
        for (int i = 0; i < keys.length; i++) {
            assertEquals(get[i], map.getDouble(keys[i]), epsilon);
        }
    }

    /**
     * Test inserting items into a MetricRevisionMap
     */
    public void testPutDouble() {

        /** Put the items into the map */
        for (int i = 0; i < keys.length; i++) {
            map.putDouble(keys[i], values[i] + 1);
        }

        /** Test that the items were put correctly */
        for (int i = 0; i < keys.length; i++) {
            assertTrue(map.containsKey(keys[i]));
            assertTrue(map.containsValue(new Double(get[i] + 1)));
            assertEquals(get[i] + 1, map.getDouble(keys[i]), epsilon);
        }
    }
}
