/*
 *  JCVSReport - Assess the Progress of a Java Project in CVS
 *
 *  This program is free software; you can redistribute it and/or modify it
 *  under the terms of the GNU General Public License.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along with
 *  this program; if not, write to the Free Software Foundation, Inc.,
 *  59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package ca.utoronto.JCVSReport.metric;

import junit.framework.TestCase;

import java.sql.Timestamp;

import java.util.Comparator;
import java.util.LinkedList;
import java.util.List;

import org.jfree.data.time.Day;

/**
 * Test Class for MetricRevision
 *
 * @author Olga Rodimina
 */
public class MetricRevisionTest extends TestCase {
    // initialize MetricRevision with values from linked list
    MetricRevision metricRevisionFromList;

    // initialize from multiple arguments specified in the constructor
    MetricRevision metricRevisionFromArguments;
    Timestamp expectedTimestamp;

    /**
     * Set up testing environment for MetricRevision
     */
    public void setUp() {

        // initialize MetricRevision from the list of values for testing
        List list = new LinkedList();
        list.add("LinesOfCode");
        list.add("file1");
        expectedTimestamp = new Timestamp(200532353);
        list.add(expectedTimestamp);
        list.add(new Double(5.0));
        list.add("rodimina");
        metricRevisionFromList = new MetricRevision(list);

        // initialize MetricRevision from the list of arguments for testing
        metricRevisionFromArguments = new MetricRevision("LinesOfCode", "file1",
                expectedTimestamp, 5.0, "rodimina");
    }

    /**
     * Tests if the metric name was initialized correctly when constructor with
     * multiple arguments was used.
     */
    public void testGetMetricNameConstructorArgs() {
        String metricName = metricRevisionFromArguments.getMetricName();
        assertEquals("LinesOfCode", metricName);
    }

    /**
     * Tests if the file name was initialized correctly when constructor with
     * multiple arguments was used.
     */
    public void testGetFileNameConstructorArgs() {
        String fileName = metricRevisionFromArguments.getFile();
        assertEquals("file1", fileName);
    }

    /**
     * Tests if the timestamp was initialized correctly when constructor with
     * multiple arguments was used.
     */
    public void testGetTimestampConstructorArgs() {
        Timestamp timestamp = metricRevisionFromArguments.getTimestamp();
        assertEquals(expectedTimestamp, timestamp);
    }

    /**
     * Tests if the day of the revision was initialized correctly when
     * constructor with multiple arguments was used.
     */
    public void testGetDayConstructorArgs() {
        assertEquals(metricRevisionFromArguments.getDay(), new Day(3, 1, 1970));
    }

    /**
     * Tests if the metric value was initialized correctly when constructor
     * with multiple arguments was used.
     */
    public void testGetMetricValueConstructorArgs() {
        double metricValue = metricRevisionFromArguments.getMetricValue();
        assertEquals(5, (int) metricValue);
    }

    /**
     * Tests if the developer name was initialized correctly when constructor
     * with multiple arguments was used.
     */
    public void testGetDeveloperConstructorArgs() {
        String developer = metricRevisionFromArguments.getDeveloper();
        assertEquals("rodimina", developer);
    }

    /**
     * Tests if the metric name was initialized correctly when constructor that
     * initialized MetricRevision for list of values was used
     */
    public void testGetMetricNameConstructorList() {
        String metricName = metricRevisionFromList.getMetricName();
        assertEquals("LinesOfCode", metricName);
    }

    /**
     * Tests if the file name was initialized correctly when constructor that
     * initialized MetricRevision for list of values was used
     */
    public void testGetFileNameConstructorList() {
        String fileName = metricRevisionFromList.getFile();
        assertEquals("file1", fileName);
    }

    /**
     * Tests if the timestamp was initialized correctly when constructor that
     * initialized MetricRevision for list of values was used
     */
    public void testGetTimestampConstructorList() {
        Timestamp timestamp = metricRevisionFromList.getTimestamp();
        assertEquals(expectedTimestamp, timestamp);
    }

    /**
     * Tests if the day of the revision was initialized correctly when
     * constructor with list was used.
     */
    public void testGetDayConstructorList() {
        assertEquals(metricRevisionFromArguments.getDay(), new Day(3, 1, 1970));
    }

    /**
     * Tests if the metric value was initialized correctly when constructor
     * that initialized MetricRevision for list of values was used
     */
    public void testGetMetricValueConstructorList() {
        double metricValue = metricRevisionFromList.getMetricValue();
        assertEquals(5, (int) metricValue);
    }

    /**
     * Tests if the developer name was initialized correctly when constructor
     * that initialized MetricRevision for list of values was used
     */
    public void testGetDeveloperConstructorList() {
        String developer = metricRevisionFromList.getDeveloper();
        assertEquals("rodimina", developer);
    }

    /**
     * Tests whether MetricRevision.byDeveloper correctly compares
     * developer names from the two metric results
     */
    public void testByDeveloperEqual() {
        Comparator c = MetricRevision.byDeveloper();
        int result = c.compare(metricRevisionFromArguments,
                metricRevisionFromList);
        assertEquals(result, 0);
    }

    /**
     * Tests whether MetricRevision.byFile correctly compares developer names
     * from the two metric results
     */
    public void testByDeveloperDifferent() {
        metricRevisionFromArguments = new MetricRevision("LinesOfCode", "file2",
                expectedTimestamp, 5.0, "james");
        Comparator c = MetricRevision.byDeveloper();
        int result = c.compare(metricRevisionFromArguments,
                metricRevisionFromList);
        assertTrue(result < 0);
    }

    /**
     * Tests whether MetricRevision.byFile correctly compares developer names
     * from the two metric results
     */
    public void testByFileEqual() {
        Comparator c = MetricRevision.byDeveloper();
        int result = c.compare(metricRevisionFromArguments,
                metricRevisionFromList);
        assertEquals(result, 0);
    }

    /**
     * Tests whether MetricRevision.byFile correctly compares developer names
     * from the two metric results
     */
    public void testByFile() {
        metricRevisionFromArguments = new MetricRevision("LinesOfCode", "file2",
                expectedTimestamp, 5.0, "james");
        Comparator c = MetricRevision.byDeveloper();
        int result = c.compare(metricRevisionFromArguments,
                metricRevisionFromList);
        assertTrue(result < 0);
    }
}
