/*
 *  JCVSReport - Assess the Progress of a Java Project in CVS
 *
 *  This program is free software; you can redistribute it and/or modify it
 *  under the terms of the GNU General Public License.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along with
 *  this program; if not, write to the Free Software Foundation, Inc.,
 *  59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package ca.utoronto.JCVSReport.metric;

import ca.utoronto.JCVSReport.MetricDatabase;

import junit.framework.TestCase;

import net.sf.bloof.Bloof;
import net.sf.bloof.db.McKoiControl;

import java.sql.Connection;

import java.util.MissingResourceException;


/**
 * Test class for MetricSet
 *
 * @author Olga Rodimina
 */
public class MetricSetTest extends TestCase {
    MetricSet metricSet;
    MetricDatabase database;

    /** Set up our set of tests
     */
    protected void setUp() {
        try {
            Connection conn = McKoiControl.create(Bloof.INTERNAL_DATABASE);
            database = new MetricDatabase(conn);
        } catch (Exception e) {
            fail("Failed to connect and initialize MetricDatabase."
                + e.toString());
        }

        metricSet = new MetricSet(database);
    }

    /**
     * Tests that ResourceBundle is returned for properties file associated with
     * the specified metric name
     */
    public void testValidMetricProps() {
        assertNotNull(MetricSet.metricProps("LinesOfCode"));
    }

    /**
     * Tests that MissingResourceException if thrown when ResourceBundles is
     * queried for the invalid metric.
     */
    public void testInvalidMetricProps() {
        boolean exception = false;

        try {
            MetricSet.metricProps("invalidMatric");
        } catch (MissingResourceException ex) {
            exception = true;
        }

        assertTrue(exception);
    }

    /**
     * Test whether correct title is returned for the specified metric
     */
    public void testValidMetricTitle() {
        String title = MetricSet.metricTitle("LinesOfCode");
        assertEquals("Lines of Code", title);
    }

    /**
     * Tests whether exception is thrown when the invalid metric is specified
     */
    public void testInvalidMetricTitle() {
        boolean exception = false;

        try {
            String title = MetricSet.metricTitle("Invalid metric");
        } catch (MissingResourceException ex) {
            exception = true;
        }

        assertTrue(exception);
    }

    /**
     * Tests whether specified metric is added to the list of metrics
     *
     * @throws Exception
     */
    public void testAddValidMetric() throws Exception {
        metricSet.addMetric("LinesOfCode");
        assertTrue(metricSet.metrics.containsKey("LinesOfCode"));
    }

}
