/*
 *  JCVSReport - Assess the Progress of a Java Project in CVS
 *
 *  This program is free software; you can redistribute it and/or modify it
 *  under the terms of the GNU General Public License.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along with
 *  this program; if not, write to the Free Software Foundation, Inc.,
 *  59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package ca.utoronto.JCVSReport.metric;

import junit.framework.TestCase;

import java.util.ResourceBundle;
import java.util.regex.Pattern;

/**
 * Test class for SyntaxTreeRegexMatchCounter
 *
 * @author Olga Rodimina
 */
public class SyntaxTreeRegexMatchCounterTest extends TestCase {
    String testJavaAST; // Test string to match regular expression
    Pattern regex; // Regular expression

    // counter that will count number of matches
    SyntaxTreeRegexMatchCounter regexCounter;

    // location of java metrics property files
    String propertyLocation = "ca.utoronto.JCVSReport.metric.properties.";

    /**
     * Sets up tests environment, including test string containing
     * contents of the class.
     */
    public void setUp() {
        regexCounter = new SyntaxTreeRegexMatchCounter();
        testJavaAST = "package ca.utoronto.JCVSReport.cvsPlugin;\n"
            + "import java.sql.Timestamp;\n" + "\n"
            + "public class History {\n" + "\n" + "    /**\n"
            + "     * @return Returns the operation.\n" + "     */ \n"
            + "    public String getOperation() {\n"
            + "        return mOperation;\n" + "    }\n" + "    /**\n"
            + "     * @param operation The operation to set.\n" + "     */ \n"
            + "    public void setOperation(final String operation) {\n"
            + "        mOperation = operation;\n" + "    }\n}\n";
    }

    /**
     * Test whether number of classes are calculated correctly  in the test
     * string
     */
    public void testNumClasses() {
        ResourceBundle props = ResourceBundle.getBundle(propertyLocation
                + "NumberOfClasses");

        // get regular expression for the metric
        regex = Pattern.compile(props.getString("regex"));
        int numMatches = regexCounter.countMatches(testJavaAST, regex);
        assertEquals(1, numMatches);
    }

    /**
     * Test whether number of imports are calculated correctly  in the test
     * string
     */
    public void testNumImports() {
        ResourceBundle props = ResourceBundle.getBundle(propertyLocation
                + "NumberOfImports");

        // get regular expression for the metric
        regex = Pattern.compile(props.getString("regex"));
        int numMatches = regexCounter.countMatches(testJavaAST, regex);
        assertEquals(1, numMatches);
    }

    /**
     * Test whether number of methods are calculated correctly  in the test
     * string
     */
    public void testNumMethods() {
        ResourceBundle props = ResourceBundle.getBundle(propertyLocation
                + "NumberOfMethods");

        // get regular expression for the metric
        regex = Pattern.compile(props.getString("regex"));
        int numMatches = regexCounter.countMatches(testJavaAST, regex);
        assertEquals(2, numMatches);
    }

    /**
     * Test whether number of test classes are calculated correctly  in the
     * test string
     */
    public void testNumTestClasses() {
        ResourceBundle props = ResourceBundle.getBundle(propertyLocation
                + "NumberOfTestClasses");

        // get regular expression for the metric
        regex = Pattern.compile(props.getString("regex"));
        int numMatches = regexCounter.countMatches(testJavaAST, regex);
        assertEquals(0, numMatches);
    }

    /**
     * Test whether number of test classes are calculated correctly  in the
     * test string
     */
    public void testNumTestMethods() {
        ResourceBundle props = ResourceBundle.getBundle(propertyLocation
                + "NumberOfTestMethods");

        // get regular expression for the metric
        regex = Pattern.compile(props.getString("regex"));
        int numMatches = regexCounter.countMatches(testJavaAST, regex);
        assertEquals(0, numMatches);
    }

    /**
     * Test whether number of test methods are calculated correctly  in the
     * test string
     */
    public void testNCSS() {
        ResourceBundle props = ResourceBundle.getBundle(propertyLocation
                + "NCSS");

        // get regular expression for the metric
        regex = Pattern.compile(props.getString("regex"));
        int numMatches = regexCounter.countMatches(testJavaAST, regex);
        assertEquals(7, numMatches);
    }

    /**
     * Test whether number of cyclomatic-complexity is correctly
     * calculated
     */
    public void testCyclomaticComplexity() {
        ResourceBundle props = ResourceBundle.getBundle(propertyLocation
                + "CyclomaticComplexity");

        // get regular expression for the metric
        regex = Pattern.compile(props.getString("regex"));
        int numMatches = regexCounter.countMatches(testJavaAST, regex);
        assertEquals(2, numMatches);
    }
}